@@ -3,7 +3,7 @@ use base 'Catalyst::Base';
 
 
 
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 
 
@@ -21,15 +21,16 @@ Catalyst::Enzyme - CRUD framework for Catalyst
 
 =head1 SYNOPSIS
 
-    #Create database
-    ... left as an exercise for the reader (actually, see the tutorial) ...
-
     #Create app
     catalyst BookShelf
+    cd BookShelf
 
     #Create View
     script\bookshelf_create.pl view TT Enzyme::TT
 
+    #Create database
+    ... left as an exercise for the reader (actually, see the tutorial) ...
+
     #Create Models for all tables
     script\bookshelf_create.pl model BookShelfDB Enzyme::CDBI dbi:SQLite:dbname=db/bookshelf.db
 
@@ -61,6 +62,13 @@ together into a unified whole. There are other ways to do this
 (obviously. This is, like... uh, Perl).
 
 
+=head2 Documentation
+
+First, look at these docs, and do the L</TUTORIAL>.
+
+Then look at L</Further Documentation>
+
+
 
 =head1 WORKING WITH ENZYME
 
@@ -96,6 +104,21 @@ faster and with less code, you need to make this your own
 framework. Change it, adapt it to your needs.
 
 
+=head2 Overview
+
+At the bottom is a L<Class::DBI> database table.
+
+On top of the table there is a Catalyst Model class (which also
+inherits from Catalyst::Enzyme::CRUD::Model). The Model class provides
+some meta data so Enzyme can display the Model objects properly.
+
+For each Model class there is a CRUD Controller class providing
+actions for create, edit, etc.
+
+There is a set of default TT templates to display the Model
+objects. You can override templates per Controller.
+
+
 =head2 Providing Meta Data
 
 Refactoring meant moving details out of templates and into general
@@ -110,8 +133,8 @@ is done in the Model class' config->{crud} hash ref.
 the View (i.e.the template?), but I don't see a way to do that right
 now.)
 
-See L<Catalyst::Enzyme::Model::CRUD> for details on what parameters
-you should set.
+See L<Catalyst::Enzyme::CRUD::Model> for details on what parameters
+you should set for each Model class.
 
 
 =head2 Adapting Controllers
@@ -174,8 +197,8 @@ Enzyme will redirect (as opposed to forward) after any data modifying
 action (the do_* actions).
 
 The reason for this is that there shouldn't be any destructive url
-lingering in the Location field in the browser (whappens when the user
-reloads the /book/destroy/34 URL? It fails if course).
+lingering in the Location field in the browser (what happens when the
+user reloads the /book/destroy/34 URL? It fails if course).
 
 
 =head2 Internationalization
@@ -187,7 +210,7 @@ Controllers, but almost all text is in the templates.
 =head2 Further Documentation
 
 Read up on the config for your Model classes:
-L<Catalyst::Enzyme::Model::CRUD>
+L<Catalyst::Enzyme::CRUD::Model>
 
 Read the source of L<Catalyst::Enzyme::CRUD::Controller> to understand
 how you can use, adapt, and extend it.
@@ -202,15 +225,20 @@ looks like with only a CRUD layer on top of the database.
 Browse to http://localhost:3000/ at regular intervals during the setup
 to see the current state of the application.
 
+If you're gonna do this yourself, the simplest thing is probably to do
+it from the t/tutorial directory. That way the database create script
+will be in place.
 
-=head2 Create Catalyst applicatoin BookShelf
+Rename the existing C<BookShelf> application directory to something
+else, open up a shell in C<tutorial> and go ahead...
+
+
+=head2 Create Catalyst application BookShelf
 
     catalyst BookShelf
     ... created files ...
-
     cd BookShelf
 
-
     script\bookshelf_server.pl
 
 Browsing to http://localhost:3000/ gets us the welcome screen.
@@ -241,7 +269,7 @@ This url doesn't exist yet, but we'll create it soon.
     script\bookshelf_create.pl view TT Enzyme::TT
     ... created files ...
 
-This created a special Enzyme TT View, standard templates in
+This creates a special Enzyme TT View, standard templates in
 ./root/base/, as well as a css file in ./root/static/css/ .
 
 The Enzyme TT View allows for overloading template fragments based on
@@ -272,15 +300,15 @@ Note: Make sure you have L<DBI::Shell> installed before running C<dbish>.
     script\bookshelf_create.pl model BookShelfDB Enzyme::CDBI dbi:SQLite:dbname=db/bookshelf.db
     ... created files ...
 
-This created the main CDBI class BookShelfDB, and table classes for
+This creates the main CDBI class BookShelfDB, and table classes for
 each table in the database.
 
-While they work fine as it is, Enzyme could use some extra meta data
-about the Model classes.
+While they work as it is, Enzyme could use some extra meta data about
+the Model classes.
 
 
 
-=head2 Configure the Book model class
+=head2 Configure the Book Model class
 
 lib\BookShelf\Model\BookShelfDB\Book.pm
 
@@ -316,20 +344,49 @@ Add crud configuration:
 
 A few things to note:
 
+            moniker => "Book",
+
 The C<Moniker> is optional and would have defaulted to Book
 anyway. But that's how to do it. So now you know.
 
+            column_monikers => { __PACKAGE__->default_column_monikers, isbn => "ISBN" },
+
 The column_monikers is optional, and except for the ISBN, this was
 also unnecessary. But since we had to override it, we had to start
 with the deafult column monikers.
 
-The rows_per_page controls paging in when listing the Books. The
-deafult is 20 rows, but Books take a little more vertical space, so
-we'll go with 10. Actually, if you'd like to see the paging feature
-right away, set it to 3. Or you could just add a few books...
+            rows_per_page => 10,
+
+The rows_per_page controls paging when listing the Books. The deafult
+is 20 rows, but Books take a little more vertical space, so we'll go
+with 10. Actually, if you'd like to see the paging feature right away,
+set it to 3. Or you could just add a few books...
 
 (Yes, this should really be a View configuration somehow.)
 
+            data_form_validator => {
+                optional => [ __PACKAGE__->columns ],
+                required => [ qw/ title format genre /],
+                constraint_methods => {
+                    isbn => { name => "fv_isbn", constraint => qr/^[\d-]+$/ },
+                },
+                missing_optional_valid => 1,
+                msgs => {
+                    format => '%s',
+                    constraints => {
+                        fv_isbn => "Not an ISBN number",
+                    },
+                },
+            },
+
+This chunk is passed to L<Data::FormValidator>, so you should
+familiarize yourself with that module at some point. The default form
+validator config makes all columns optional.
+
+                missing_optional_valid => 1,
+
+This should always be in your dfv config, otherwise updates with empty
+values will not work.
 
 
 =head2 Create Book CRUD Controller
@@ -344,9 +401,9 @@ by adding a CRUD controller.
 
 =head2 Test the book CRUD
 
-When you surf around and check out all the books you may notice that
-Borrower is a number, and so is Genre. That's because we haven't
-configured the other Models yet.
+When you surf around at L<http://localhost:3000/book> and check out
+all the books you may notice that Borrower is a number, and so is
+Genre. That's because we haven't configured the other Models yet.
 
 When you add new Books, note how the C<title> is mandatory. See what
 happens if you omit it.
@@ -359,7 +416,8 @@ that's actually a proper constraint for ISBN numbers).
 
 =head2 Add links between the tables
 
-Edit the root/base/header.tt and add this inside the content div:
+Edit the root/base/header.tt and add this inside the content div so we
+can jump between the tables:
 
     <a href="/book/">Book</a> |
     <a href="/borrower/">Borrower</a> |
@@ -404,11 +462,16 @@ The normal way to import the default FormValidator::Constraints would be
 
     use Data::FormValidator::Constraints qw(:regexp_common :closures);
 
-but that imports subs like email and phone into this
+but that imports subs like C<email> and C<phone> into this
 namespace. But... since this is our model class, there is already
 field accessors by that names in our symbol table, and that will
-clash. Hence the use of Data::FormValidator::Constraints::email.
+clash. Hence the use of C<Data::FormValidator::Constraints::email> in
+the config.
 
+    __PACKAGE__->columns(Stringify=> qw/name/);
+
+Thanks to the Stringify, the Borrower now displays as the name, not
+the PK in the Book listing.
 
 
 =item lib\BookShelf\Model\BookShelfDB\Genre.pm
@@ -438,13 +501,14 @@ That's all folks!
 Now read the rest of the documentation to learn how to modify the
 application further and perhaps start building on top of it.
 
+L</Further Documentation>
 
 
-=head2 SEE ALSO
+=head1 SEE ALSO
 
 
 
-=head2 TODO
+=head1 TODO
 
 Tests, lots of tests!
 
